@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------------
-# Copyright 2006-2021 UT-Battelle, LLC. See LICENSE for more information.
+# Copyright 2006-2022 UT-Battelle, LLC. See LICENSE for more information.
 # -------------------------------------------------------------------------------
 import os
 import sys
@@ -11,7 +11,7 @@ import logging
 import socket
 import time
 from multiprocessing import Queue, Process, set_start_method
-from .configobj import ConfigObj
+from configobj import ConfigObj
 from . import ipsLogging
 from .services import ServicesProxy
 from .componentRegistry import ComponentID, ComponentRegistry
@@ -225,6 +225,7 @@ class ConfigurationManager:
         self.platform_conf['PROCS_PER_NODE'] = int(self.platform_conf.get('PROCS_PER_NODE', 0))
         self.platform_conf['CORES_PER_NODE'] = int(self.platform_conf.get('CORES_PER_NODE', 0))
         self.platform_conf['SOCKETS_PER_NODE'] = int(self.platform_conf.get('SOCKETS_PER_NODE', 0))
+        self.platform_conf['GPUS_PER_NODE'] = int(self.platform_conf.get('GPUS_PER_NODE', 0))
         self.platform_conf['USE_ACCURATE_NODES'] = use_accurate_nodes
         self.platform_conf['MPIRUN_VERSION'] = mpirun_version
 
@@ -377,7 +378,7 @@ class ConfigurationManager:
             portal_conf['DATA_FILES'] = ''
             portal_conf['OUTPUT_FILES'] = ''
             portal_conf['NPROC'] = 1
-            portal_conf['LOG_LEVEL'] = 'WARNING'
+            portal_conf['LOG_LEVEL'] = 'INFO'
             try:
                 portal_conf['USER'] = self.sim_map[self.fwk_sim_name].sim_conf['USER']
             except KeyError:
