@@ -1,13 +1,13 @@
 # -------------------------------------------------------------------------------
-# Copyright 2006-2021 UT-Battelle, LLC. See LICENSE for more information.
+# Copyright 2006-2022 UT-Battelle, LLC. See LICENSE for more information.
 # -------------------------------------------------------------------------------
 import os
 import sys
 import select
 import time
 from multiprocessing.connection import Listener
+from configobj import ConfigObj
 from .component import Component
-from .configobj import ConfigObj
 
 
 class Driver(Component):
