@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # -------------------------------------------------------------------------------
-# Copyright 2006-2021 UT-Battelle, LLC. See LICENSE for more information.
+# Copyright 2006-2022 UT-Battelle, LLC. See LICENSE for more information.
 # -------------------------------------------------------------------------------
 
 import os
@@ -12,7 +12,7 @@ import tempfile
 import re
 import time
 from multiprocessing.connection import Client
-from ipsframework.configobj import ConfigObj
+from configobj import ConfigObj
 from ipsframework import platformspec
 from ipsframework.ipsutil import which
 
